PAWpySeed: /home/kyle/Research/projects/pawpyseed/pawpyseed/core/radial.h Source File

PAWpySeed Parallel C/Python package for numerical analysis of PAW DFT wavefunctions

- Main Page
- Classes
- Files

- File List
- File Members

radial.h
Go to the documentation of this file.
1
6 #ifndef RADIAL_H
7 #define RADIAL_H
8
9 #include <complex.h>
10
17 double complex offsite_wave_overlap(double* dcoord, double* r1, double* f1, double** spline1, int size1,
18 double* r2, double* f2, double** spline2, int size2,
19 double* lattice, int l1, int m1, int l2, int m2);
20
28 double complex reciprocal_offsite_wave_overlap(double* dcoord,
29 double* k1, double* f1, double** s1, int size1,
30 double* k2, double* f2, double** s2, int size2,
31 double* lattice, int l1, int m1, int l2, int m2);
32
33 #endif
reciprocal_offsite_wave_overlap
double complex reciprocal_offsite_wave_overlap(double *dcoord, double *k1, double *f1, double **s1, int size1, double *k2, double *f2, double **s2, int size2, double *lattice, int l1, int m1, int l2, int m2)
offsite_wave_overlap
double complex offsite_wave_overlap(double *dcoord, double *r1, double *f1, double **spline1, int size1, double *r2, double *f2, double **spline2, int size2, double *lattice, int l1, int m1, int l2, int m2)